@@ -3,7 +3,6 @@ module Tmuxinator
     include Tmuxinator::Util
     include Tmuxinator::Deprecations
     include Tmuxinator::Hooks::Project
-    include Tmuxinator::WemuxSupport
 
     RBENVRVM_DEP_MSG = <<-M
     DEPRECATION: rbenv/rvm-specific options have been replaced by the
@@ -27,12 +26,12 @@ module Tmuxinator
     now, use the 'synchronize: after' option.
     M
     PRE_DEP_MSG = <<-M
-    DEPRECATION: The `pre` option has been replaced by project hooks and will
-    not be supported anymore.
+    DEPRECATION: The `pre` option has been replaced by project hooks (`on_project_start` and
+    `on_project_restart`) and will be removed in a future release.
     M
     POST_DEP_MSG = <<-M
-    DEPRECATION: The `post` option has been replaced by project hooks and will
-    not be supported anymore.
+    DEPRECATION: The `post` option has been replaced by project hooks (`on_project_stop` and
+    `on_project_exit`) and will be removed in a future release.
     M
 
     attr_reader :yaml
@@ -91,7 +90,7 @@ module Tmuxinator
       raise "Cannot force_attach and force_detach at the same time" \
         if @force_attach && @force_detach
 
-      load_wemux_overrides if wemux?
+      extend Tmuxinator::WemuxSupport if wemux?
     end
 
     def render
@@ -171,7 +170,7 @@ module Tmuxinator
       # to server: Connection refused" error message and non-zero exit status
       # if no tmux sessions exist.
       # Please see issues #402 and #414.
-      sessions = `#{tmux_command} ls 2> /dev/null`
+      sessions = `#{tmux} ls 2> /dev/null`
 
       # Remove any escape sequences added by `shellescape` in Project#name.
       # Escapes can result in: "ArgumentError: invalid multibyte character"
@@ -378,5 +377,9 @@ module Tmuxinator
     def parsed_parameters(parameters)
       parameters.is_a?(Array) ? parameters.join("; ") : parameters
     end
+
+    def wemux?
+      yaml["tmux_command"] == "wemux"
+    end
   end
 end
