@@ -1,6 +1,8 @@
 module Tmuxinator
   module TmuxVersion
     SUPPORTED_TMUX_VERSIONS = [
+      "3.0a",
+      3.0,
       "2.9a",
       2.9,
       2.8,
